@@ -52,7 +52,7 @@ class SqliteDao:
         self.conn.execute(query)
 
     def drop_index(self, index_name):
-        query = "DROP TABLE {}".format(index_name)
+        query = "DROP INDEX {}".format(index_name)
         self.conn.execute(query)
 
     def create_table(self, table_name, column_dict, index_dict=None):
